@@ -324,20 +324,20 @@ class Cursor(common.DBAPICursor):
         _logger.info("fetching all")
         return self._fetch_all()
 
-    def fetchoneOld(self):
-        _logger.info("fetching one")
-        if len(self._batch) == 0:
-            self.fetch_batch()
-            if len(self._batch) == 0:
-                return None
-        self.rows_count += len(self._batch)
-        if self.rows_count <= 1000:
-            row = self._batch.pop()
-        else:
-            row = None
-            # reset row counter for next query execution
-            self.rows_count = 0
-        return row
+    # def fetchoneOld(self):
+    #     _logger.info("fetching one")
+    #     if len(self._batch) == 0:
+    #         self.fetch_batch()
+    #         if len(self._batch) == 0:
+    #             return None
+    #     self.rows_count += len(self._batch)
+    #     if self.rows_count <= 1000:
+    #         row = self._batch.pop()
+    #     else:
+    #         row = None
+    #         # reset row counter for next query execution
+    #         self.rows_count = 0
+    #     return row
 
     def fetchone(self):
         _logger.info("fetch returning the batch itself")
@@ -345,29 +345,16 @@ class Cursor(common.DBAPICursor):
             self.fetch_batch()
             if len(self._batch) == 0:
                 return None
-        # self.rows_count += len(self._batch)
-        # if self.rows_count <= 1000:
-        #     row = self._batch
-        # else:
-        #     row = None
-        #     # reset row counter for next query execution
-        #     self.rows_count = 0
-        row = self._batch
+        # in order to stop fetching next batch, we are limiting to one batch - 1000 records
+        self.rows_count += len(self._batch)
+        if self.rows_count <= 1000:
+            row = self._batch
+        else:
+            row = None
+            # reset row counter for next query execution
+            self.rows_count = 0
         return row
 
-    # def fetchone(self):
-    #     _logger.info("fetching one")
-    #     client = self.connection.client
-    #     buffer = client.getNextResultRow(self._query_id)
-    #
-    #     if not buffer:
-    #         return None
-    #
-    #     buffer = BytesIO(buffer)
-    #     dis = DataInputStream(buffer)
-    #     value_array = read_values_from_array(self._query_columns_description, dis)
-    #     return value_array
-
     def poll(self, get_progress_update=True):
         """Poll for and return the raw status data provided by the Hive Thrift REST API.
         :returns: ``ttypes.TGetOperationStatusResp``
